==> huaweicloudsdkdws-3.1.78-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/show_workload_queue_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWorkloadQueueRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'queue_name': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'queue_name': 'queue_name'
    }

    def __init__(self, cluster_id=None, queue_name=None):
        """ShowWorkloadQueueRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 集群ID
        :type cluster_id: str
        :param queue_name: 资源队列名
        :type queue_name: str
        """
        
        

        self._cluster_id = None
        self._queue_name = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.queue_name = queue_name

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ShowWorkloadQueueRequest.

        集群ID

        :return: The cluster_id of this ShowWorkloadQueueRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ShowWorkloadQueueRequest.

        集群ID

        :param cluster_id: The cluster_id of this ShowWorkloadQueueRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def queue_name(self):
        """Gets the queue_name of this ShowWorkloadQueueRequest.

        资源队列名

        :return: The queue_name of this ShowWorkloadQueueRequest.
        :rtype: str
        """
        return self._queue_name

    @queue_name.setter
    def queue_name(self, queue_name):
        """Sets the queue_name of this ShowWorkloadQueueRequest.

        资源队列名

        :param queue_name: The queue_name of this ShowWorkloadQueueRequest.
        :type queue_name: str
        """
        self._queue_name = queue_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWorkloadQueueRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/show_workload_queue_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWorkloadQueueRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'queue_name': 'str',
        'logical_cluster_name': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'queue_name': 'queue_name',
        'logical_cluster_name': 'logical_cluster_name'
    }

    def __init__(self, cluster_id=None, queue_name=None, logical_cluster_name=None):
        """ShowWorkloadQueueRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 集群ID
        :type cluster_id: str
        :param queue_name: 资源队列名
        :type queue_name: str
        :param logical_cluster_name: 逻辑集群名称。非逻辑集群模式下该字段不填,逻辑集群模式下需指定逻辑集群名称。
        :type logical_cluster_name: str
        """
        
        

        self._cluster_id = None
        self._queue_name = None
        self._logical_cluster_name = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.queue_name = queue_name
        if logical_cluster_name is not None:
            self.logical_cluster_name = logical_cluster_name

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ShowWorkloadQueueRequest.

        集群ID

        :return: The cluster_id of this ShowWorkloadQueueRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ShowWorkloadQueueRequest.

        集群ID

        :param cluster_id: The cluster_id of this ShowWorkloadQueueRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def queue_name(self):
        """Gets the queue_name of this ShowWorkloadQueueRequest.

        资源队列名

        :return: The queue_name of this ShowWorkloadQueueRequest.
        :rtype: str
        """
        return self._queue_name

    @queue_name.setter
    def queue_name(self, queue_name):
        """Sets the queue_name of this ShowWorkloadQueueRequest.

        资源队列名

        :param queue_name: The queue_name of this ShowWorkloadQueueRequest.
        :type queue_name: str
        """
        self._queue_name = queue_name

    @property
    def logical_cluster_name(self):
        """Gets the logical_cluster_name of this ShowWorkloadQueueRequest.

        逻辑集群名称。非逻辑集群模式下该字段不填,逻辑集群模式下需指定逻辑集群名称。

        :return: The logical_cluster_name of this ShowWorkloadQueueRequest.
        :rtype: str
        """
        return self._logical_cluster_name

    @logical_cluster_name.setter
    def logical_cluster_name(self, logical_cluster_name):
        """Sets the logical_cluster_name of this ShowWorkloadQueueRequest.

        逻辑集群名称。非逻辑集群模式下该字段不填,逻辑集群模式下需指定逻辑集群名称。

        :param logical_cluster_name: The logical_cluster_name of this ShowWorkloadQueueRequest.
        :type logical_cluster_name: str
        """
        self._logical_cluster_name = logical_cluster_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWorkloadQueueRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
